<?php

/**
 * Helper functions for taxonomy interactions
 */


/**
 * Creates vocabulary by array of properties
 *
 * @param array $vocabulary - array of fields to insert into vocabulary and vocabulary_node_types tables
 * @return int vocabulary id
 */
function _add_vocabulary($vocabulary) {
	$query  = "INSERT INTO {vocabulary} ";
	$query .= "(name,description,help,relations,hierarchy,multiple,required,tags) ";
	$query .= "VALUES ('%s','%s','%s',%d,%d,%d,%d,%d)";

	db_query($query,$vocabulary['name'],$vocabulary['description'],$vocabulary['help'],
			 $vocabulary['relations'],$vocabulary['hierarchy'],$vocabulary['multiple'],
			 $vocabulary['required'],$vocabulary['tags']);
			 
	$vid = db_last_insert_id('vocabulary','vid');
	
	//add nodes using new vocabulary
	foreach ($vocabulary['nodes'] as $nodetype) {
		$query = "INSERT INTO {vocabulary_node_types} (vid,type) VALUES (%d,'%s')";
		db_query($query,$vid,$nodetype);
	}
	
	return $vid;
}


/**
 * Adds term to vocabulary
 *
 * @param Array $term - fields to add
 * @param int $vocabulary - vocabulary id
 * @return term id
 */
function _add_term($term,$vocabulary) {
	//save term to term_data
	$query  = "INSERT INTO {term_data} (vid,name,description,weight) ";
	$query .= "VALUES (%d,'%s','%s',%d)";
	db_query($query,$vocabulary,$term['name'],$term['description'],$term['weight']);
	$tid = db_last_insert_id('term_data','tid');
	//save to term_hierarchy (0, there are no parents to our terms)
	db_query("INSERT INTO {term_hierarchy} (tid,parent) VALUES (%d,0)",$tid);
	//return term id
	return $tid;
} //function _add_term


/**
 * Removes connection between term and node
 *
 * @param int $tid - term id
 * @param int $nid - node id
 */
function _remove_term_from_node($tid,$nid) {
	$query = "DELETE FROM {term_node} WHERE (tid=%d) AND (nid=%d)";
	db_query($query,$tid,$nid);
} //function _remode_term_from_node


/**
 * Adds connection between term and node
 *
 * @param int $tid - term id
 * @param int $nid - node id
 */
function _add_term_to_node($tid,$nid) {
	$query = "INSERT INTO {term_node} (tid,nid,vid) VALUES (%d,%d,%d)";
	db_query($query,$tid,$nid,$nid);
} //function _add_term_to_node


/**
 * Change node term from one to another
 *
 * @param int $old_tid - term to change from
 * @param int $new_tid - term to change to
 * @param int $nid - node id
 */
function _change_node_term($old_tid,$new_tid,$nid) {
	$query = "UPDATE {term_node} SET tid=%d WHERE (tid=%d) AND (nid=%d)";
	db_query($query,$new_tid,$old_tid,$nid);
} //function _change_node_term


/**
 * Returns term ids for vocabulary
 *
 * @param int $vid - vocabulary id
 * @return array - terms array
 */
function _get_vocabulary_tids($vid) {
	$query = "SELECT tid FROM {term_data} WHERE vid=%d";
	$result = db_query($query,$vid);
	$term_tids = array();
	$entry = db_fetch_object($result);
	while ($entry) {
		$term_tids[] = $entry->tid;
		$entry = db_fetch_object($result);
	}
	return $term_tids;
} //function _get_vocabulary_tids
